@@ -19,9 +19,9 @@ def run(context, cfg_mgr):
 def main(workflows):
   cfg_mgr = CfgMgr(main_config="/etc/laboro/laboro.yml")
   context = Context(logger=LogMgr(Vault()), config_mgr=cfg_mgr)
-  logging.getLogger().log_section("LABORO", "Bootstrapping")
+  logging.getLogger("laboro.main").log_section("LABORO", "Bootstrapping")
   for workflow_cfg in workflows:
-    logging.getLogger().vault.clear()
+    logging.getLogger("laboro.main").vault.clear()
     cfg_mgr.workflow_config = workflow_cfg
     run(context=context, cfg_mgr=cfg_mgr)
 
