@@ -26,7 +26,7 @@ class Handler:
       level = logging.CRITICAL
       exit_code = f"{kind.__name__}: {value}"
     exit_msg += f" {name} / {session} with {exit_code}"
-    logging.getLogger().log_section("WORKFLOW", exit_msg, level=level)
+    logging.getLogger("laboro.main").log_section("WORKFLOW", exit_msg, level=level)
     if kind is not None and kind != SystemExit:
-      if logging.getLogger().getEffectiveLevel() <= logging.DEBUG:
+      if logging.getLogger("laboro.main").getEffectiveLevel() <= logging.DEBUG:
         traceback.print_exc()
