@@ -47,7 +47,7 @@ class Module:
     def wrapper(self, *args, **kwargs):
       try:
         method = func.__name__
-        methods = self.specification["methods"]
+        methods = self.specification.get("methods") or dict()
         method = [meth for meth in methods if meth["name"] == method][0]
         Validator().validate_method_args(method, kwargs)
         method_args = Validator().set_default_method_args(method, kwargs)
