@@ -1,3 +1,4 @@
+import copy
 import yaml
 import logging
 import builtins
@@ -128,7 +129,7 @@ class Validator:
 
   def _set_default_args(self, obj, args):
     if obj.get("args") is not None:
-      default_args = obj.get("args").copy()
+      default_args = copy.deepcopy(obj.get("args"))
       for arg in default_args:
         if arg.get("default") is not None:
           arg["value"] = arg["default"]
@@ -167,15 +168,15 @@ class Validator:
       try:
         allowed_types = arg_type if isinstance(arg_type, list) else [arg_type]
         allow = [isinstance(value, getattr(builtins, allowed))
-                for allowed in allowed_types]
+                 for allowed in allowed_types]
         if not any(allow):
           msg = {"type": "BadArgTypeError",
-                "message": f"Expected type one of {allowed_types} / received {type(value)} for {arg}."}
+                 "message": f"Expected type one of {allowed_types} / received {type(value)} for {arg}."}
           logging.critical(f"[{msg['type']}] {msg['message']}")
           raise LaboroError(f"[{msg['type']}] {msg['message']}")
       except AttributeError as err:
         msg = {"type": "UnknownTypeError",
-              "message": f"Unknown type '{arg_type}' for argument {arg}."}
+               "message": f"Unknown type '{arg_type}' for argument {arg}."}
         logging.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
