@@ -1,3 +1,4 @@
+import copy
 import logging
 from laboro.logic.processor import Processor
 from laboro.workflow.method import Method
@@ -50,7 +51,7 @@ class Action:
 
   def _get_instance_args(self, instance):
     if "args" in instance:
-      interpolated = instance["args"].copy()
+      interpolated = copy.deepcopy(instance["args"])
       for key, value in interpolated.items():
         interpolated[key] = Processor().process_arg(self.ctx, str(value))
       return interpolated
