@@ -1,4 +1,5 @@
 import re
+import copy
 import logging
 from laboro.logic.processor import Processor
 
@@ -55,7 +56,7 @@ class Method:
 
   def _get_method_args(self):
     if self.args is not None:
-      interpolated = self.args.copy()
+      interpolated = copy.deepcopy(self.args)
       for key, value in interpolated.items():
         interpolated[key] = Processor().process_arg(self.ctx, str(value))
       return interpolated
